==> tasks-v1.8.8.zip: tasks/messages/pt-BR/base.php <==
<?php
return [
  '1 Day before' => '1 dia antes',
  '1 Month before' => '1 mês antes',
  '1 Week before' => '1 semana antes',
  '2 Days before' => '2 dias antes',
  '2 Weeks before' => '2 Semanas antes',
  '3 Weeks before' => '3 semanas antes',
  '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Usuários designados</strong> têm permissão para processar esta tarefa.',
  '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> exclusão da tarefa',
  '<strong>Create</strong> task list' => '<strong>Criar</strong> lista de tarefas',
  '<strong>Edit</strong> task' => 'Tarefa <strong>Editar</strong>',
  '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tarefas',
  '<strong>New</strong> Task' => '<strong>Nova</strong> tarefa',
  '<strong>Task</strong> Overview' => '<strong>Tarefa</strong> Visão geral',
  '<strong>Tasks</strong>' => '<strong>Tarefas</strong>',
  '<strong>Tasks</strong> module configuration' => 'Configuração do módulo <strong>Tarefas</strong>',
  '<strong>Your</strong> tasks' => '<strong>Suas</strong> tarefas',
  'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Um widget é um elemento adicionado à barra lateral de um fluxo. Nesse caso, ele fornece aos usuários uma breve visão geral de suas tarefas.',
  'Accept Task' => 'Aceitar tarefa',
  'Add Deadline to space calendar' => 'Adicionar Prazo ao calendário do espaço',
  'Add checkpoint...' => 'Adicionar ponto de verificação ...',
  'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Adicione pontos de verificação à tarefa para destacar as etapas individuais necessárias para concluí-la.',
  'Add entry to main navigation' => 'Adicionar entrada à navegação principal',
  'Add reminder' => 'Adicionar lembrete',
  'Add responsible users' => 'Adicione usuários responsáveis',
  'Add schedule to the space calendar' => 'Adicionar programação ao calendário do espaço',
  'Add task' => 'Adicionar tarefa',
  'Add to space calendar' => 'Add to space calendar',
  'Additional options' => 'Opções adicionais',
  'All Day' => 'Todo dia',
  'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permite que o usuário crie novas tarefas, ele poderá editar e excluir as próprias tarefas',
  'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite ao usuário criar, excluir e editar tarefas e listas e também classificar tarefas e listas',
  'Allows the user to process unassigned tasks' => 'Permite que o usuário processe tarefas não atribuídas',
  'Already requested' => 'Já solicitado',
  'Any user with a "Process unassigned tasks" permission can work on this task' => 'Qualquer usuário com a permissão "Processar tarefas não atribuídas" pode trabalhar nessa tarefa',
  'Anyone can work on this task!' => 'Qualquer um pode trabalhar nessa tarefa!',
  'Assign myself' => 'Atribuir a mim mesmo',
  'Assign users' => 'Atribuir usuários',
  'Assigned' => 'Atribuída',
  'Assigned users' => 'Usuários atribuídos',
  'Assignment' => 'Tarefa',
  'Assignments:' => 'Atribuições:',
  'At least 1 Hour before' => 'Pelo menos 1 hora antes',
  'At least 2 Hours before' => 'Pelo menos 2 horas antes',
  'Attachments' => 'Anexos',
  'Begin Task' => 'Iniciar tarefa',
  'Checklist Items' => 'Itens da lista de verificação',
  'Checklist:' => 'Lista de controle:',
  'Checkpoints' => 'Pontos de verificação',
  'Choose if you want the module to appear in the main navigation.' => 'Escolha se deseja que o módulo apareça na navegação principal.',
  'Close' => 'Fechar',
  'Color' => 'Cor',
  'Completed' => 'Concluída',
  'Completed lists' => 'Listas concluídas',
  'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configure o módulo Tarefas para atender aos seus requisitos e necessidades específicas. Você pode definir configurações individuais e, por exemplo, decidir se um widget é exibido.',
  'Continue Review' => 'Continuar revisão',
  'Create tasks' => 'Criar tarefas',
  'Created by me' => 'Criado por mim',
  'Date' => 'Data',
  'Deadline at' => 'Prazo em',
  'Deadline: ' => 'Data limite:',
  'Delete' => 'Apagar',
  'Delete list' => 'Excluir lista',
  'Description' => 'Descrição',
  'Do not remind' => 'Não lembre',
  'Do you really want to delete this task?' => 'Deseja realmente excluir esta tarefa?',
  'Don\'t add to calendar' => 'Não adicionar ao calendário',
  'Drag entry' => 'Arrastar entrada',
  'Edit' => 'Alterar',
  'Edit item (empty field will be removed)...' => 'Editar item (o campo vazio será removido) ...',
  'Edit list' => 'Lista de edição',
  'End' => 'Fim',
  'End Date' => 'Data Final',
  'End Time' => 'Hora de término',
  'End date' => 'Data final',
  'End time must be after start time!' => 'A hora de término precisa ser depois da hora de início!',
  'Extend deadline request' => 'Estender solicitação de prazo',
  'Filter' => 'Filtro',
  'Filter by status' => 'Filtrar por estado',
  'Filter by title' => 'Filtrar por título',
  'Filter tasks' => 'Filtrar tarefas',
  'Finish Task' => 'Concluir tarefa',
  'General' => 'Geral',
  'General Settings' => 'Configurações Gerais',
  'Hide this list once all tasks are completed' => 'Ocultar esta lista quando todas as tarefas estiverem concluídas',
  'I\'m assigned' => 'Estou designado',
  'I\'m responsible' => 'eu sou responsável',
  'If empty any user can complete the task.' => 'Se estiver vazio, qualquer usuário pode concluir a tarefa.',
  'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se nenhum usuário designado for selecionado, todos os membros do espaço com permissão para processar tarefas não atribuídas poderão processar a tarefa.',
  'In Progress' => 'Em progresso',
  'In Review' => 'Em revisão',
  'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Se nenhum usuário designado for selecionado, todos os membros do espaço com permissão para processar tarefas não atribuídas poderão processar a tarefa.',
  'Invalid task list selection.' => 'Seleção de lista de tarefas inválida.',
  'Let Task Review' => 'Deixe a revisão da tarefa',
  'Main Navigation' => 'Navegação Principal',
  'Manage tasks' => 'Gerenciar tarefas',
  'Maximum number of entries in widget' => 'Número máximo de entradas no widget',
  'Module Widget' => 'Módulo Widget',
  'New list or search' => 'Nova lista ou pesquisa',
  'No Scheduling set for this Task' => 'Nenhum agendamento definido para esta tarefa',
  'No pending tasks found' => 'Nenhuma tarefa pendente encontrada',
  'No results found for the given filter.' => 'Nenhum resultado encontrado para o filtro fornecido.',
  'Open Task' => 'Tarefa aberta',
  'Other Tasks' => 'Outras tarefas',
  'Overdue' => 'Vencidas',
  'Overview' => 'Visão geral',
  'Parent Task' => 'Tarefa pai',
  'Pending' => 'Pendente',
  'Pending Review' => 'Revisão pendente',
  'Process unassigned tasks' => 'Processar tarefas não atribuídas',
  'Ready For Review' => 'Pronto para revisão',
  'Receive Notifications for Task Reminder.' => 'Receba notificações para o lembrete de tarefas.',
  'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Receba notificações de tarefas (atualizações de prazo, alterações de status ...).',
  'Reject Task' => 'Rejeitar Tarefa',
  'Remind Mode' => 'Modo Lembrar',
  'Reminder' => 'Lembrete',
  'Reminder sent' => 'Lembrete enviado',
  'Reminders' => 'Lembretes',
  'Request extension' => 'Solicitar extensão',
  'Request sent' => 'Pedido enviado',
  'Reset Task' => 'Redefinir tarefa',
  'Responsible' => 'Responsável',
  'Responsible users' => 'Usuários responsáveis',
  'Review by responsible user required' => 'É necessário revisar pelo usuário responsável',
  'Scheduling' => 'Agendamento',
  'Show widget in Spaces' => 'Mostrar widget nos Espaços',
  'Show widget on Dashboard' => 'Mostrar widget no painel',
  'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar mais {count} concluídas {countTasks,plural,=1{task} other{tasks}}',
  'Sort Order' => 'Ordem de Classificação',
  'Sort order' => 'Ordem de classificação',
  'Spaces' => 'Espaços',
  'Start' => 'Iniciar',
  'Start Date' => 'Data de Inicio',
  'Start Time' => 'Hora de início',
  'Start date' => 'Data de início',
  'Starting at' => 'Começando às',
  'Status' => 'Status',
  'Task' => 'Tarefa',
  'Task List' => 'Lista de tarefas',
  'Task Users have been notified' => 'Os usuários da tarefa foram notificados',
  'Task content ID' => 'ID do conteúdo da tarefa',
  'Task {task} in space {spaceName} ends at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} termina em {dateTime}.',
  'Task {task} in space {spaceName} starts at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} inicia em {dateTime}.',
  'Tasks' => 'Tarefas',
  'Tasks: Reminder' => 'Tarefas: Lembrete',
  'This task can only be processed by assigned and responsible users.' => 'Esta tarefa pode ser processada apenas por usuários designados e responsáveis.',
  'This task requires to be reviewed by a responsible' => 'Esta tarefa precisa ser revisada por um responsável',
  'Time Zone' => 'Fuso horário',
  'Title' => 'Título',
  'Title and Color' => 'Título e Cor',
  'Title of your task list' => 'Título da sua lista de tarefas',
  'Today' => 'Hoje',
  'Unsorted' => 'não triados',
  'View Online' => 'Ver Online',
  'You are assigned!' => 'Você está designado!',
  'You are responsible!' => 'Você é responsável!',
  'You have insufficient permissions to perform that operation!' => 'Você não tem permissões suficientes para executar essa operação!',
  'Your Reminder for task {task}' => 'Seu lembrete para a tarefa {task}',
  'ending Review' => 'revisão final',
  'view all' => 'ver tudo',
  '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} restantes',
  '{displayName} is assigned to this task' => '{displayName} está atribuído a esta tarefa',
  '{displayName} is responsible for this task' => '{displayName} é responsável por esta tarefa',
  '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} designou você como pessoa responsável na tarefa {task} do espaço {spaceName}.',
  '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} designou você para a tarefa {task} no espaço {spaceName}.',
  '{userName} completed Task {task} in space {spaceName}.' => '{userName} concluiu a tarefa {task} no espaço {spaceName}.',
  '{userName} completed task {task}.' => '{userName} completou a tarefa {task}.',
  '{userName} finished task {task}.' => '{userName} tarefa finalizada {task}.',
  '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} mudou o prazo final para a tarefa {task} no espaço {spaceName}.',
  '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} reabriu a tarefa {task} no espaço {spaceName}.',
  '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} rejeitou a tarefa {task} no espaço {spaceName} como incompleta.',
  '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcou a tarefa {task} no espaço {spaceName} como concluída.',
  '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} solicita uma extensão de prazo para a tarefa {task} no espaço {spaceName}.',
  '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} solicita que você reveja a tarefa {task} no espaço {spaceName}.',
  '{userName} reset task {task}.' => '{userName} redefiniu a tarefa {task}.',
  '{userName} reviewed task {task}.' => '{userName} revisou a tarefa {task}.',
  '{userName} started working on Task {task} in space {spaceName}.' => '{userName} começou a trabalhar na tarefa {task} no espaço {spaceName}.',
  '{userName} works on task {task}.' => '{userName} trabalhou na tarefa {task}.',
];

==> tasks-v1.9.1.zip: tasks/messages/pt-BR/base.php <==
<?php
return [
  '1 Day before' => '1 dia antes',
  '1 Month before' => '1 mês antes',
  '1 Week before' => '1 semana antes',
  '2 Days before' => '2 dias antes',
  '2 Weeks before' => '2 Semanas antes',
  '3 Weeks before' => '3 semanas antes',
  '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Usuários designados</strong> têm permissão para processar esta tarefa.',
  '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> exclusão da tarefa',
  '<strong>Create</strong> task list' => '<strong>Criar</strong> lista de tarefas',
  '<strong>Edit</strong> task' => 'Tarefa <strong>Editar</strong>',
  '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tarefas',
  '<strong>New</strong> Task' => '<strong>Nova</strong> tarefa',
  '<strong>Task</strong> Overview' => '<strong>Tarefa</strong> Visão geral',
  '<strong>Tasks</strong>' => '<strong>Tarefas</strong>',
  '<strong>Tasks</strong> module configuration' => 'Configuração do módulo <strong>Tarefas</strong>',
  '<strong>Your</strong> tasks' => '<strong>Suas</strong> tarefas',
  'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Um widget é um elemento adicionado à barra lateral de um fluxo. Nesse caso, ele fornece aos usuários uma breve visão geral de suas tarefas.',
  'Accept Task' => 'Aceitar tarefa',
  'Add Deadline to space calendar' => 'Adicionar Prazo ao calendário do espaço',
  'Add checkpoint...' => 'Adicionar ponto de verificação ...',
  'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Adicione pontos de verificação à tarefa para destacar as etapas individuais necessárias para concluí-la.',
  'Add entry to main navigation' => 'Adicionar entrada à navegação principal',
  'Add reminder' => 'Adicionar lembrete',
  'Add responsible users' => 'Adicione usuários responsáveis',
  'Add schedule to the space calendar' => 'Adicionar programação ao calendário do espaço',
  'Add task' => 'Adicionar tarefa',
  'Add to space calendar' => 'Add to space calendar',
  'Additional options' => 'Opções adicionais',
  'All Day' => 'Todo dia',
  'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permite que o usuário crie novas tarefas, ele poderá editar e excluir as próprias tarefas',
  'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite ao usuário criar, excluir e editar tarefas e listas e também classificar tarefas e listas',
  'Allows the user to process unassigned tasks' => 'Permite que o usuário processe tarefas não atribuídas',
  'Already requested' => 'Já solicitado',
  'Assign myself' => 'Atribuir a mim mesmo',
  'Assign users' => 'Atribuir usuários',
  'Assigned users' => 'Usuários atribuídos',
  'Assignment' => 'Tarefa',
  'Assignments' => 'Tarefas',
  'At least 1 Hour before' => 'Pelo menos 1 hora antes',
  'At least 2 Hours before' => 'Pelo menos 2 horas antes',
  'Attachments' => 'Anexos',
  'Begin Task' => 'Iniciar tarefa',
  'Checklist Items' => 'Itens da lista de verificação',
  'Checklist:' => 'Lista de controle:',
  'Checkpoints' => 'Pontos de verificação',
  'Choose if you want the module to appear in the main navigation.' => 'Escolha se deseja que o módulo apareça na navegação principal.',
  'Close' => 'Fechar',
  'Color' => 'Cor',
  'Completed' => 'Concluída',
  'Completed lists' => 'Listas concluídas',
  'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configure o módulo Tarefas para atender aos seus requisitos e necessidades específicas. Você pode definir configurações individuais e, por exemplo, decidir se um widget é exibido.',
  'Continue Review' => 'Continuar revisão',
  'Create tasks' => 'Criar tarefas',
  'Created by me' => 'Criado por mim',
  'Date' => 'Data',
  'Deadline' => 'Prazo final',
  'Deadline: ' => 'Data limite:',
  'Delete' => 'Apagar',
  'Delete list' => 'Excluir lista',
  'Description' => 'Descrição',
  'Do not remind' => 'Não lembre',
  'Do you really want to delete this task?' => 'Deseja realmente excluir esta tarefa?',
  'Don\'t add to calendar' => 'Não adicionar ao calendário',
  'Edit' => 'Alterar',
  'Edit item (empty field will be removed)...' => 'Editar item (o campo vazio será removido) ...',
  'Edit list' => 'Lista de edição',
  'End' => 'Fim',
  'End Date' => 'Data Final',
  'End Time' => 'Hora de término',
  'End date' => 'Data final',
  'End time must be after start time!' => 'A hora de término precisa ser depois da hora de início!',
  'Extend deadline request' => 'Estender solicitação de prazo',
  'Filter' => 'Filtro',
  'Filter by status' => 'Filtrar por estado',
  'Filter by title' => 'Filtrar por título',
  'Filter tasks' => 'Filtrar tarefas',
  'Finish Task' => 'Concluir tarefa',
  'General' => 'Geral',
  'General Settings' => 'Configurações Gerais',
  'Hide this list once all tasks are completed' => 'Ocultar esta lista quando todas as tarefas estiverem concluídas',
  'I\'m assigned' => 'Estou designado',
  'I\'m responsible' => 'eu sou responsável',
  'ID' => 'ID',
  'If empty any user can complete the task.' => 'Se estiver vazio, qualquer usuário pode concluir a tarefa.',
  'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Se nenhum usuário designado for selecionado, todos os membros do espaço com permissão para processar tarefas não atribuídas poderão processar a tarefa.',
  'In Progress' => 'Em progresso',
  'In Review' => 'Em revisão',
  'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Se nenhum usuário designado for selecionado, todos os membros do espaço com permissão para processar tarefas não atribuídas poderão processar a tarefa.',
  'Invalid task list selection.' => 'Seleção de lista de tarefas inválida.',
  'Let Task Review' => 'Deixe a revisão da tarefa',
  'Main Navigation' => 'Navegação Principal',
  'Manage tasks' => 'Gerenciar tarefas',
  'Maximum number of entries in widget' => 'Número máximo de entradas no widget',
  'Module Widget' => 'Módulo Widget',
  'New list or search' => 'Nova lista ou pesquisa',
  'No Scheduling set for this Task' => 'Nenhum agendamento definido para esta tarefa',
  'No pending tasks found' => 'Nenhuma tarefa pendente encontrada',
  'No results found for the given filter.' => 'Nenhum resultado encontrado para o filtro fornecido.',
  'Open Task' => 'Tarefa aberta',
  'Other Tasks' => 'Outras tarefas',
  'Overdue' => 'Vencidas',
  'Overview' => 'Visão geral',
  'Parent Task' => 'Tarefa pai',
  'Pending' => 'Pendente',
  'Pending Review' => 'Revisão pendente',
  'Process unassigned tasks' => 'Processar tarefas não atribuídas',
  'Ready For Review' => 'Pronto para revisão',
  'Receive Notifications for Task Reminder.' => 'Receba notificações para o lembrete de tarefas.',
  'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Receba notificações de tarefas (atualizações de prazo, alterações de status ...).',
  'Reject Task' => 'Rejeitar Tarefa',
  'Remind Mode' => 'Modo Lembrar',
  'Reminder' => 'Lembrete',
  'Reminder sent' => 'Lembrete enviado',
  'Reminders' => 'Lembretes',
  'Request Review' => 'Solicitar revisão',
  'Request extension' => 'Solicitar extensão',
  'Request sent' => 'Pedido enviado',
  'Reset Task' => 'Redefinir tarefa',
  'Responsible' => 'Responsável',
  'Responsible users' => 'Usuários responsáveis',
  'Review by responsible user required' => 'É necessário revisar pelo usuário responsável',
  'Scheduling' => 'Agendamento',
  'Show widget in Spaces' => 'Mostrar widget nos Espaços',
  'Show widget on Dashboard' => 'Mostrar widget no painel',
  'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar mais {count} concluídas {countTasks,plural,=1{task} other{tasks}}',
  'Sort Order' => 'Ordem de Classificação',
  'Sort order' => 'Ordem de classificação',
  'Spaces' => 'Espaços',
  'Start' => 'Iniciar',
  'Start Date' => 'Data de Inicio',
  'Start Time' => 'Hora de início',
  'Start date' => 'Data de início',
  'Starting at' => 'Começando às',
  'Status' => 'Status',
  'Task' => 'Tarefa',
  'Task List' => 'Lista de tarefas',
  'Task Users have been notified' => 'Os usuários da tarefa foram notificados',
  'Task content ID' => 'ID do conteúdo da tarefa',
  'Task {task} in space {spaceName} ends at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} termina em {dateTime}.',
  'Task {task} in space {spaceName} starts at {dateTime}.' => 'A tarefa {task} no espaço {spaceName} inicia em {dateTime}.',
  'Tasks' => 'Tarefas',
  'Tasks: Reminder' => 'Tarefas: Lembrete',
  'This task requires to be reviewed by a responsible' => 'Esta tarefa precisa ser revisada por um responsável',
  'Time Zone' => 'Fuso horário',
  'Title' => 'Título',
  'Title and Color' => 'Título e Cor',
  'Title of your task list' => 'Título da sua lista de tarefas',
  'Today' => 'Hoje',
  'Unsorted' => 'não triados',
  'View Online' => 'Ver Online',
  'You have insufficient permissions to perform that operation!' => 'Você não tem permissões suficientes para executar essa operação!',
  'Your Reminder for task {task}' => 'Seu lembrete para a tarefa {task}',
  'view all' => 'ver tudo',
  '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} restantes',
  '{displayName} is assigned to this task' => '{displayName} está atribuído a esta tarefa',
  '{displayName} is responsible for this task' => '{displayName} é responsável por esta tarefa',
  '{displayName} is task creator' => '{displayName} é o criador da tarefa',
  '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} designou você como pessoa responsável na tarefa {task} do espaço {spaceName}.',
  '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} designou você para a tarefa {task} no espaço {spaceName}.',
  '{userName} completed Task {task} in space {spaceName}.' => '{userName} concluiu a tarefa {task} no espaço {spaceName}.',
  '{userName} completed task {task}.' => '{userName} completou a tarefa {task}.',
  '{userName} finished task {task}.' => '{userName} tarefa finalizada {task}.',
  '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} mudou o prazo final para a tarefa {task} no espaço {spaceName}.',
  '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} reabriu a tarefa {task} no espaço {spaceName}.',
  '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} rejeitou a tarefa {task} no espaço {spaceName} como incompleta.',
  '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcou a tarefa {task} no espaço {spaceName} como concluída.',
  '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} solicita uma extensão de prazo para a tarefa {task} no espaço {spaceName}.',
  '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} solicita que você reveja a tarefa {task} no espaço {spaceName}.',
  '{userName} reset task {task}.' => '{userName} redefiniu a tarefa {task}.',
  '{userName} reviewed task {task}.' => '{userName} revisou a tarefa {task}.',
  '{userName} started working on Task {task} in space {spaceName}.' => '{userName} começou a trabalhar na tarefa {task} no espaço {spaceName}.',
  '{userName} works on task {task}.' => '{userName} trabalhou na tarefa {task}.',
];
